pub enum UnminedTxId {
Legacy(Hash),
Witnessed(WtxId),
}Expand description
A unique identifier for an unmined transaction, regardless of version.
“The transaction ID of a version 4 or earlier transaction is the SHA-256d hash of the transaction encoding in the pre-v5 format described above.
The transaction ID of a version 5 transaction is as defined in ZIP-244.
A v5 transaction also has a wtxid (used for example in the peer-to-peer protocol) as defined in ZIP-239.“ Spec: Transaction Identifiers
Variants
Legacy(Hash)
A legacy unmined transaction identifier.
Used to uniquely identify unmined version 1-4 transactions.
(After v1-4 transactions are mined, they can be uniquely identified
using the same Hash.)
Witnessed(WtxId)
Implementations
Sourceimpl UnminedTxId
impl UnminedTxId
Sourcepub fn from_legacy_id(legacy_tx_id: Hash) -> UnminedTxId
pub fn from_legacy_id(legacy_tx_id: Hash) -> UnminedTxId
Create a new UnminedTxId using a v1-v4 legacy transaction ID.
Correctness
This method must only be used for v1-v4 transaction IDs.
Hash does not uniquely identify unmined v5
transactions.
Sourcepub fn mined_id(&self) -> Hash
pub fn mined_id(&self) -> Hash
Return the unique ID that will be used if this transaction gets mined into a block.
Correctness
For v1-v4 transactions, this method returns an ID which changes if this transaction’s effects (spends and outputs) change, or if its authorizing data changes (signatures, proofs, and scripts).
But for v5 transactions, this ID uniquely identifies the transaction’s effects.
Sourcepub fn mined_id_mut(&mut self) -> &mut Hash
pub fn mined_id_mut(&mut self) -> &mut Hash
Returns a mutable reference to the unique ID that will be used if this transaction gets mined into a block.
See Self::mined_id for details.
Sourcepub fn auth_digest(&self) -> Option<AuthDigest>
pub fn auth_digest(&self) -> Option<AuthDigest>
Return the digest of this transaction’s authorizing data, (signatures, proofs, and scripts), if it is a v5 transaction.
Sourcepub fn auth_digest_mut(&mut self) -> Option<&mut AuthDigest>
pub fn auth_digest_mut(&mut self) -> Option<&mut AuthDigest>
Returns a mutable reference to the digest of this transaction’s authorizing data, (signatures, proofs, and scripts), if it is a v5 transaction.