VerifiedUnminedTx

Struct VerifiedUnminedTx 

pub struct VerifiedUnminedTx {
    pub transaction: UnminedTx,
    pub miner_fee: Amount<NonNegative>,
    pub legacy_sigop_count: u32,
    pub conventional_actions: u32,
    pub unpaid_actions: u32,
    pub fee_weight_ratio: f32,
    pub time: Option<DateTime<Utc>>,
    pub height: Option<Height>,
    pub spent_outputs: Arc<Vec<Output>>,
}
A verified unmined transaction, and the corresponding transaction fee.

This transaction has been fully verified, in the context of the mempool.

Fields

transaction: UnminedTx

The unmined transaction.

miner_fee: Amount<NonNegative>

The transaction fee for this unmined transaction.

legacy_sigop_count: u32

The number of legacy transparent signature operations in this transaction.

This is the legacy sigop count only (GetLegacySigOpCount()). The mempool adds P2SH sigops (GetP2SHSigOpCount()) when checking MAX_STANDARD_TX_SIGOPS.

conventional_actions: u32

The number of conventional actions for transaction, as defined by ZIP-317.

The number of actions is limited by MAX_BLOCK_BYTES, so it fits in a u32.

unpaid_actions: u32

The number of unpaid actions for transaction, as defined by ZIP-317 for block production.

The number of actions is limited by MAX_BLOCK_BYTES, so it fits in a u32.

fee_weight_ratio: f32

The fee weight ratio for transaction, as defined by ZIP-317 for block production.

This is not consensus-critical, so we use f32 for efficient calculations when the mempool holds a large number of transactions.

time: Option<DateTime<Utc>>

The time the transaction was added to the mempool, or None if it has not reached the mempool yet.

height: Option<Height>

The tip height when the transaction was added to the mempool, or None if it has not reached the mempool yet.

spent_outputs: Arc<Vec<Output>>

The spent outputs for this transaction’s transparent inputs.

Used by mempool policy checks (AreInputsStandard, GetP2SHSigOpCount). Empty for transactions with no transparent inputs or in test contexts.

Implementations

Source

impl VerifiedUnminedTx

pub fn new( transaction: UnminedTx, miner_fee: Amount<NonNegative>, legacy_sigop_count: u32, spent_outputs: Arc<Vec<Output>>, ) -> Result<Self, Error>

Create a new verified unmined transaction from an unmined transaction, its miner fee, its legacy sigop count, and the spent outputs for its transparent inputs.

pub fn pays_conventional_fee(&self) -> bool

Returns true if the transaction pays at least the ZIP-317 conventional fee.

pub fn cost(&self) -> u64

The cost in bytes of the transaction, as defined in ZIP-401.

A reflection of the work done by the network in processing them (proof and signature verification; networking overheads; size of in-memory data structures).

Each transaction has a cost, which is an integer defined as…

pub fn eviction_weight(&self) -> u64

The computed eviction weight of a verified unmined transaction as part of the mempool set, as defined in ZIP-317 and ZIP-401.

Standard Rule

Each transaction also has an eviction weight, which is cost + low_fee_penalty, where low_fee_penalty is 40000 if the transaction pays a fee less than the conventional fee, otherwise 0. The conventional fee is currently defined in ZIP-317.

zcashd and zebrad limit the size of the mempool as described in ZIP-401. This specifies a low fee penalty that is added to the “eviction weight” if the transaction pays a fee less than the conventional transaction fee. This threshold is modified to use the new conventional fee formula.